:mod:`euphorie.content.fti`
===========================

.. automodule:: euphorie.content.fti

.. autointerface:: IConstructionFilter
   :members:

.. autoclass:: ConditionalDexterityFTI
   :members:

.. autofunction:: check_fti_paste_allowed
